@@ -26,9 +26,9 @@ if __name__ == '__main__':     #enclosing required because of multiprocessing
     print("LaueNN path is", laueNN_path)
     
     ## Load the json of material and extinctions
-    with open(os.path.join(laueNN_path, 'lauetools\material.json'),'r') as f:
+    with open(os.path.join(laueNN_path, 'lauetools','material.json'),'r') as f:
         dict_Materials = json.load(f)
-    with open(os.path.join(laueNN_path, 'lauetools\extinction.json'),'r') as f:
+    with open(os.path.join(laueNN_path, 'lauetools','extinction.json'),'r') as f:
         extinction_json = json.load(f)
 
     ## Modify the dictionary values to add new entries
@@ -41,9 +41,9 @@ if __name__ == '__main__':     #enclosing required because of multiprocessing
     ## verify if extinction is present in CrystalParameters.py file of lauetools (Manually done for now)
 
     ## dump the json back with new values
-    with open(os.path.join(laueNN_path, 'lauetools\material.json'), 'w') as fp:
+    with open(os.path.join(laueNN_path, 'lauetools','material.json'), 'w') as fp:
         json.dump(dict_Materials, fp)
-    with open(os.path.join(laueNN_path, 'lauetools\extinction.json'), 'w') as fp:
+    with open(os.path.join(laueNN_path, 'lauetools','extinction.json'), 'w') as fp:
         json.dump(extinction_json, fp)
 
     ## Verify if the material is added to the library or not;
@@ -58,7 +58,7 @@ if __name__ == '__main__':     #enclosing required because of multiprocessing
     ## User Input dictionary with parameters
     ## In case of only one phase/material, keep same value for material_ and material1_ key
     input_params = {
-                    "global_path" : r"C:\Users\purushot\Desktop\LaueNN_script",
+                    "global_path" : os.getcwd(),
                     "prefix" : "_2phase",                 ## prefix for the folder to be created for training dataset
 
                     "material_": ["GaN", "Si"],             ## same key as used in dict_LaueTools
@@ -79,7 +79,7 @@ if __name__ == '__main__':     #enclosing required because of multiprocessing
 
                     "include_small_misorientation": False, ## to include additional data with small angle misorientation
                     "misorientation": 5, ##only used if "include_small_misorientation" is True
-                    "maximum_angle_to_search":20, ## Angle of radial distribution to reconstruct the histogram (in deg)
+                    "maximum_angle_to_search":90, ## Angle of radial distribution to reconstruct the histogram (in deg)
                     "step_for_binning" : 0.1,      ## bin widht of angular radial distribution in degree
                     
                     # =============================================================================
@@ -104,10 +104,10 @@ if __name__ == '__main__':     #enclosing required because of multiprocessing
                     # =============================================================================
                     # ## Prediction parameters
                     # =============================================================================
-                    "experimental_directory": r"D:\some_projects\GaN\BLC12834\NW1",
+                    "experimental_directory": os.getcwd(),
                     "experimental_prefix": r"nw1_",
-                    "grid_size_x" : 61,            ## Grid X and Y limit to generate the simulated dataset (a rectangular scan region)
-                    "grid_size_y" : 61,
+                    "grid_size_x" : 1,            ## Grid X and Y limit to generate the simulated dataset (a rectangular scan region)
+                    "grid_size_y" : 2,
                     
                     # =============================================================================
                     # ## Prediction Settings
@@ -132,11 +132,11 @@ if __name__ == '__main__':     #enclosing required because of multiprocessing
                     # =============================================================================
                     # # [PEAKSEARCH]
                     # =============================================================================
-                    "intensity_threshold" : 2,
-                    "boxsize" : 10,
-                    "fit_peaks_gaussian" : 1,
-                    "FitPixelDev" : 15,
-                    "NumberMaxofFits" : 3000,
+                    "intensity_threshold" : 2,## for skimage this is of image standard deviation
+                    "boxsize" : 10,## for skimage this is box size to fit
+                    "fit_peaks_gaussian" : 1,## for skimage this is of no sense
+                    "FitPixelDev" : 15, ## for skimage this is distance between peaks to avoid
+                    "NumberMaxofFits" : 3000,## for skimage this is maximum leastquare attempts before giving up
                     "mode": "skimage",
 
                     # =============================================================================
@@ -159,9 +159,9 @@ if __name__ == '__main__':     #enclosing required because of multiprocessing
                     }
 
     generate_dataset = True
-    train_network = False
-    write_config_GUI = False
-    run_prediction = False
+    train_network = True
+    write_config_GUI = True
+    run_prediction = True
     prediction_GUI = False
     # =============================================================================
     # END OF USER INPUT
@@ -314,7 +314,7 @@ if __name__ == '__main__':     #enclosing required because of multiprocessing
         SG1 = input_params["SG"][1]
         
         ## read hkl information from a fit file in case too large HKLs
-        manual_hkl_list=True
+        manual_hkl_list=False
         if manual_hkl_list:
             ##read from a text file (fit file)
             import numpy as np
